@@ -11,7 +11,7 @@ from PDielec.AbinitOutputReader import AbinitOutputReader
 from PDielec.QEOutputReader import QEOutputReader
 from PDielec.PhonopyOutputReader import PhonopyOutputReader
 import PDielec.Utilities as Utilities
-from multiprocess import Pool
+from multiprocessing import Pool
 
 def set_affinity_on_worker():
     """When a new worker process is created, the affinity is set to all CPUs"""
@@ -31,7 +31,7 @@ def main():
     if len(sys.argv) <= 1 :
         print('p2cif -program program filenames .....', file=sys.stderr)
         print('  \"program\" must be one of \"abinit\", \"castep\", \"crystal\", \"gulp\"       ', file=sys.stderr)
-        print('           \"phonopy\", \"qe\", \"vasp\", \"auto\"                                ', file=sys.stderr)
+        print('           \"phonopy\", \"qe\", \"vasp\", \"experiment\", \"auto\"               ', file=sys.stderr)
         print('           The default is auto, so the program tries to guess the package from   ', file=sys.stderr)
         print('           the contents of the directory.  However this is not fool-proof!       ', file=sys.stderr)
         print('           If phonopy is used it must be followed by the QM package              ', file=sys.stderr)
@@ -64,7 +64,7 @@ def main():
         print('Please use -program to define the package used to generate the output files',file=sys.stderr)
         exit()
 
-    if not program in ['abinit','castep','crystal','gulp','qe','vasp','phonopy','auto']:
+    if not program in ['abinit','castep','crystal','gulp','qe','vasp','phonopy','experiment','auto']:
         print('Program is not recognised: ',program,file=sys.stderr)
         exit()
 
